numina.datamodel — Model of data — Numina 0.20.dev0 documentation

# `numina.datamodel` — Model of data

class `numina.datamodel.` `DataModel`(name='UNKNOWN', mappings=None)

  Model of the Data being processed

  Parameters: | name (str) – Name of the DataModel mappings (dict, optional) – A dictionary of str keys and values convertibles to FITSKeyExtractor

  `do_sky_correction`(img)

    Perform sky correction

  `gather_info`(dframe)

    Obtain a summary of information about the image.

  `gather_info_dframe`(img)

    Obtain a summary of information about the image.

  `gather_info_hdu`(hdulist)

    Obtain a summary of information about the image.

  `get_darktime`(img)

    Obtain DARKTIME

  `get_data`(img)

    Obtain the primary data from the image

  `get_exptime`(img)

    Obtain EXPTIME

  `get_header`(img)

    Obtain the primary header from the image

  `get_imgid`(img)

    Obtain a unique identifier of the image.

    Parameters: | img (astropy.io.fits.HDUList) –
    Returns: | Identification of the image
    Return type: | str

  `get_quality_control`(img)

    Obtain quality control flag from the image.

  `get_variance`(img)

    Obtain the variance of the primary data from the image

class `numina.datamodel.` `FITSKeyExtractor`(values)

  Extract values from FITS images